<?php
class UBC_CLF_Lite_Tha_Hooks {

	/**
	 * Set up our tha hooks
	 *
	 * @since 1.0.0
	 *
	 */
	 public function init() {

		// Custom header part.
		add_action( 'tha_header_bottom', array( $this, 'add_ubc_wp_clf_lite_custom_header' ), 10, 2 );

		// Off-canvas main menu.
		add_action( 'tha_header_after', array( $this, 'add_off_canvas_main_menu_tha_header_after' ), 10, 2 );

		// Custom sidebar setup.
		add_action( 'tha_sidebar_top', array( $this, 'add_ubc_wp_clf_lite_sidebar_title_header' ), 10, 2 );

		// Add banner to content.
		add_action( 'tha_content_before', array( $this, 'add_banner_image_before_primary_content' ), 10, 2 );

		// Offcavas main sidebar.
		add_action( 'tha_content_after', array( $this, 'add_add_off_canvas_sidebar_after_content' ), 10, 2 );

		// Offcavas for notifications or feedback.
		add_action( 'tha_footer_before', array( $this, 'add_feedback_notification_box' ), 10, 2 );

		// Offcavas for notifications or feedback.
		add_action( 'tha_footer_before', array( $this, 'add_feedback_notification_box' ), 10, 2 );

	}/* init() */

	/**
	 * Template for sidebar using tha_sidebar_top()
	 *
	 * @since 1.0.0
	 */
	public function add_ubc_wp_clf_lite_sidebar_title_header() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/custom-sidebar.php' );

	} /* add_ubc_wp_clf_lite_sidebar_title_header() */


	/**
	 * Template for off-canvas main menu content using tha_header_after()
	 *
	 * @since 0.1.9
	 */
	public function add_off_canvas_main_menu_tha_header_after() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/content-main-menu.php' );

	} /* add_ubc_wp_clf_lite_sidebar_title_header() */

	/**
	 * Template for custom header part using tha_header_top()
	 *
	 * @since 1.0.0
	 */
	public function add_ubc_wp_clf_lite_custom_header() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/custom-header-part.php' );

	} /* add_ubc_wp_clf_lite_custom_header() */


	/**
	 * Template for custom header part using tha_primary_content()
	 *
	 * @since 1.0.0
	 */
	public function add_banner_image_before_primary_content() {

		// First get custom banner data
		$data = get_theme_mod( 'header_image_data' );

		if ( ! $data ) {
			return;
		}

		// Turn that data into an array.
		$data = get_object_vars( $data );

		// Get image id.
		$data_id = is_array( $data ) && isset( $data['attachment_id'] ) ? $data['attachment_id'] : false;

		// If post has thumbnail get the attachement id or use the custom header id.
		$attachment_id = ( true == has_post_thumbnail() ) ? get_post_thumbnail_id() : $data_id;

		if ( has_header_image() || has_post_thumbnail() ) : ?>

			<div class="site-banner">
				<?php echo wp_get_attachment_image( $attachment_id , 'full' ); ?>
			</div>

		<?php endif; // End header image check.

	} /* add_banner_image_before_primary_content() */

	/**
	 * Template for feedback off canvas window for notifications or feedback using tha_footer_before()
	 *
	 * @since 0.1.6
	 */
	public function add_feedback_notification_box() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/content-feedback.php' );

	} /* add_feedback_notification_box() */

	/**
	 * Template for sidebar off canvas window using tha_content_after()
	 *
	 * @since 0.1.9
	 */
	public function add_add_off_canvas_sidebar_after_content() {

		require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/content-main-sidebar.php' );

	} /* add_add_off_canvas_sidebar_after_content() */

}

// Initialize our child theme changes.
add_action( 'after_setup_theme', 'after_setup_theme_ubc_clf_lite_tha_hooks_init', 15 );


/**
 * Initialize the UBC_CLF_Lite_Customizer class on after_setup_theme so we're
 * up and running AFTER the parent theme (priority 15)
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 */

function after_setup_theme_ubc_clf_lite_tha_hooks_init() {

	$UBC_CLF_Lite_Tha_Hooks = new UBC_CLF_Lite_Tha_Hooks();
	$UBC_CLF_Lite_Tha_Hooks->init();

}/* after_setup_theme_ubc_clf_lite_tha_hooks_init() */
